@@ -9,6 +9,7 @@ URL_SCHEME_RE = re.compile(r'^[a-z][a-z0-9.+-]*://', re.IGNORECASE)
 
 HTTP_POST = 'POST'
 HTTP_GET = 'GET'
+HTTP_OPTIONS = 'OPTIONS'
 
 # Various separators used in args
 SEPARATOR_HEADER = ':'
@@ -131,10 +132,3 @@ class RequestType(enum.Enum):
     FORM = enum.auto()
     MULTIPART = enum.auto()
     JSON = enum.auto()
-
-
-EMPTY_STRING = ''
-OPEN_BRACKET = '['
-CLOSE_BRACKET = ']'
-BACKSLASH = '\\'
-HIGHLIGHTER = '^'
